@@ -46,7 +46,9 @@ class Insider:
         return self.dns.service_info(name)
 
     def acquire_domain(self, email, password, user_domain):
-        return self.dns.acquire(email, password, user_domain)
+        result = self.dns.acquire(email, password, user_domain)
+        self.cron.on()
+        return result
 
     def drop_domain(self):
         self.dns.drop()
